%global srcname tyxml

Summary:  Type-safe Xml trees in OCaml
Name:     ocaml-tyxml
Version:  4.5.0
Release:  %mkrel 5
License:  LGPLv2 with exception
Group:    Development/OCaml
URL:      https://ocsigen.org/tyxml/
Source0:        https://github.com/ocsigen/tyxml/releases/download/%{version}/%{srcname}-%{version}.tbz

BuildRequires: ocaml-alcotest-devel
BuildRequires: ocaml-compiler
BuildRequires: ocaml-astring-devel
BuildRequires: ocaml-dune >= 2.0
BuildRequires: ocaml-markup-devel >= 0.7.2
BuildRequires: ocaml-ppxlib-devel
BuildRequires: ocaml-re-devel >= 1.5.0
BuildRequires: ocaml-seq-devel
BuildRequires: ocaml-uutf-devel >= 1.0.0

%description
Tyxml is a library that makes it almost impossible for your OCaml programs
to generate wrong XML output, using static typing.  Modules exist for
XHTML1, HTML5 and SVG.  Tyxml also defines pretty printers for these types.


%package      devel
Summary:      Development files for %{name}
Group:        Development/OCaml
Requires:     %{name} = %{version}-%{release}
Requires:       ocaml-re-devel%{?_isa}
Requires:       ocaml-seq-devel%{?_isa}
Requires:       ocaml-uutf-devel%{?_isa}

%description devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%package        syntax
Summary:        Common layer for the JSX and PPX syntaxes for TyXML

%description    syntax
This package contains common code used by both the JSX and the PPX
syntaxes for TyXML.

%package        syntax-devel
Summary:        Development files for %{name}-syntax
Requires:       %{name}-syntax%{?_isa} = %{version}-%{release}
Requires:       ocaml-ppxlib-devel%{?_isa}

%description    syntax-devel
The %{name}-syntax-devel package contains libraries and signature files
for developing applications that use %{name}-syntax.

%package        jsx
Summary:        JSX syntax for writing TyXML documents
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-syntax%{?_isa} = %{version}-%{release}

%description    jsx
This package enables writing TyXML documents with reasons' JSX syntax,
from textual trees to reactive virtual DOM trees.

  open Tyxml
  let to_ocaml = <a href="ocaml.org"> "OCaml!" </a>;

%package        jsx-devel
Summary:        Development files for %{name}-jsx
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}-syntax-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}-jsx%{?_isa} = %{version}-%{release}
Requires:       ocaml-ppxlib-devel%{?_isa}

%description    jsx-devel
The %{name}-jsx-devel package contains libraries and signature files for
developing applications that use %{name}-jsx.

%package        ppx
Summary:        PPX for writing TyXML documents with HTML syntax
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    ppx
This package contains PPX for writing TyXML documents with HTML syntax.

  open Tyxml
  let%%html to_ocaml = "<a href='ocaml.org'>OCaml!</a>"

The TyXML PPX is compatible with all TyXML instance, from textual trees
to reactive virtual DOM trees.

%package        ppx-devel
Summary:        Development files for %{name}-ppx
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}-ppx%{?_isa} = %{version}-%{release}
Requires:       ocaml-markup-devel%{?_isa}
Requires:       ocaml-ppxlib-devel%{?_isa}

%description    ppx-devel
The %{name}-ppx-devel package contains libraries and signature files for
developing applications that use %{name}-ppx.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
dune build %{?_smp_mflags} @install

%install
dune install --destdir=%{buildroot}

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

%check
# As of version 4.4.0, the tyxml-jsx tests fail due to lack of the reason
# package in Fedora.
dune runtest -p tyxml,tyxml-syntax,tyxml-ppx

%files
%doc CHANGES.md README.md
%license LICENSE
%dir %{_libdir}/ocaml/%{srcname}/
%dir %{_libdir}/ocaml/%{srcname}/functor/
%{_libdir}/ocaml/%{srcname}/META
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmi
%{_libdir}/ocaml/%{srcname}/functor/*.cma
%{_libdir}/ocaml/%{srcname}/functor/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxs
%{_libdir}/ocaml/%{srcname}/functor/*.cmxs
%endif

%files devel
%{_libdir}/ocaml/%{srcname}/dune-package
%{_libdir}/ocaml/%{srcname}/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmxa
%{_libdir}/ocaml/%{srcname}/functor/*.a
%{_libdir}/ocaml/%{srcname}/functor/*.cmx
%{_libdir}/ocaml/%{srcname}/functor/*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmt
%{_libdir}/ocaml/%{srcname}/%{srcname}*.cmti
%{_libdir}/ocaml/%{srcname}/%{srcname}*.mli
%{_libdir}/ocaml/%{srcname}/functor/*.cmt
%{_libdir}/ocaml/%{srcname}/functor/*.cmti
%{_libdir}/ocaml/%{srcname}/functor/*.mli

%files syntax
%dir %{_libdir}/ocaml/%{srcname}-syntax/
%{_libdir}/ocaml/%{srcname}-syntax/META
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmxs
%endif

%files syntax-devel
%{_libdir}/ocaml/%{srcname}-syntax/dune-package
%{_libdir}/ocaml/%{srcname}-syntax/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmt
%{_libdir}/ocaml/%{srcname}-syntax/%{srcname}*.cmti
%{_libdir}/ocaml/%{srcname}-syntax/*.mli

%files jsx
%dir %{_libdir}/ocaml/%{srcname}-jsx/
%{_libdir}/ocaml/%{srcname}-jsx/META
%{_libdir}/ocaml/%{srcname}-jsx/ppx.exe
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cmxs
%endif

%files jsx-devel
%{_libdir}/ocaml/%{srcname}-jsx/dune-package
%{_libdir}/ocaml/%{srcname}-jsx/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}-jsx/%{srcname}*.cmt

%files ppx
%dir %{_libdir}/ocaml/%{srcname}-ppx/
%dir %{_libdir}/ocaml/%{srcname}-ppx/internal/
%{_libdir}/ocaml/%{srcname}-ppx/META
%{_libdir}/ocaml/%{srcname}-ppx/ppx.exe
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cma
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cmi
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cma
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cmxs
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmxs
%endif

%files ppx-devel
%{_libdir}/ocaml/%{srcname}-ppx/dune-package
%{_libdir}/ocaml/%{srcname}-ppx/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.a
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cmx
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cmxa
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.a
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmx
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmxa
%endif
%{_libdir}/ocaml/%{srcname}-ppx/%{srcname}*.cmt
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmt
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.cmti
%{_libdir}/ocaml/%{srcname}-ppx/internal/*.mli



%changelog
* Sun Dec 11 2022 pterjan <pterjan> 4.5.0-5.mga9
+ Revision: 1920634
- Rebuild for new ppxlib

* Sat Oct 15 2022 neoclust <neoclust> 4.5.0-4.mga9
+ Revision: 1897018
- Rebuild against new ocaml-base

* Fri May 20 2022 pterjan <pterjan> 4.5.0-3.mga9
+ Revision: 1859456
- Rebuild for OCaml 4.14

* Wed May 18 2022 pterjan <pterjan> 4.5.0-2.mga9
+ Revision: 1858611
- Rebuild for several updated ocaml dependencies

* Fri Oct 15 2021 tv <tv> 4.5.0-1.mga9
+ Revision: 1751555
- Version 4.5.0
- Drop all patches

* Thu Mar 25 2021 tv <tv> 4.4.0-1.mga9
+ Revision: 1709978
- 4.4.0
- Apply upstream merge request to migrate to ppxlib
- Disable doc as it is broken
- Disable failing testsuite

* Sun Jan 10 2021 pterjan <pterjan> 4.3.0-5.mga8
+ Revision: 1670820
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 4.3.0-4.mga8
+ Revision: 1551892
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 4.3.0-3.mga8
+ Revision: 1546054
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 tv <tv> 4.3.0-2.mga8
+ Revision: 1485691
- fix deps

* Wed Jan 29 2020 tv <tv> 4.3.0-1.mga8
+ Revision: 1485255
- make devel pkg pulls what it needs

* Wed Jan 29 2020 tv <tv> 4.3.0-0.1.mga8
+ Revision: 1485253
- new release + rebuild for ocaml-4.10
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 3.2.1-6.mga6
+ Revision: 1056448
- Rebuild for fix in ocaml

* Wed Feb 17 2016 daviddavid <daviddavid> 3.2.1-5.mga6
+ Revision: 964475
- fix Requires on ocaml-camlp4-devel

* Fri Feb 12 2016 umeabot <umeabot> 3.2.1-4.mga6
+ Revision: 956672
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2.1-3.mga5
+ Revision: 745659
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.1-2.mga5
+ Revision: 683119
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 malo <malo> 3.2.1-1.mga5
+ Revision: 674095
- update to 3.2.1

* Sat Oct 19 2013 umeabot <umeabot> 2.2.0-4.mga4
+ Revision: 535764
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 malo <malo> 2.2.0-3.mga4
+ Revision: 482476
- add upstream patch for new ocamlnet compatibility

* Sun Jan 13 2013 umeabot <umeabot> 2.2.0-2.mga3
+ Revision: 361672
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 12 2012 malo <malo> 2.2.0-1.mga3
+ Revision: 329919
- new version 2.2.0

* Sat Dec 01 2012 malo <malo> 2.1-5.mga3
+ Revision: 324083
- removed optional ocamlduce dependency
+ fwang <fwang>
- rebuild for new ocaml
+ blue_prawn <blue_prawn>
- rebuild for new ocaml 4.00
- new rpm group for ocaml
- new rpm group for ocaml and documentation

* Thu Jun 28 2012 malo <malo> 2.1-1.mga3
+ Revision: 264737
- update to 2.1

* Sun Apr 22 2012 malo <malo> 2.0.1-4.mga2
+ Revision: 232713
- adding missing requires to camlp4

* Mon Apr 09 2012 malo <malo> 2.0.1-3.mga2
+ Revision: 229855
- adding missing requires to ocaml-ocamlnet

* Fri Feb 17 2012 malo <malo> 2.0.1-2.mga2
+ Revision: 210085
- missing requires to ocamlduce

* Wed Feb 08 2012 malo <malo> 2.0.1-1.mga2
+ Revision: 206236
- imported package ocaml-tyxml

